use crate::actors::libvirt_actor;
use crate::actors::libvirt_actor::LibVirtActor;
use crate::libvirt_lib_structures::{DomainXML, DomainXMLUuid};
use crate::libvirt_rest_structures::HypervisorInfo;
use actix::Addr;

#[derive(Clone)]
pub struct LibVirtClient(pub Addr<LibVirtActor>);

impl LibVirtClient {
    /// Get hypervisor info
    pub async fn get_info(&self) -> anyhow::Result<HypervisorInfo> {
        self.0.send(libvirt_actor::GetHypervisorInfo).await?
    }

    /// Update a domain
    pub async fn update_domain(&self, xml: DomainXML) -> anyhow::Result<DomainXMLUuid> {
        self.0.send(libvirt_actor::DefineDomainReq(xml)).await?
    }
}
