#[derive(serde::Serialize, serde::Deserialize)]
pub struct DomainXMLUuid(pub uuid::Uuid);

impl DomainXMLUuid {
    pub fn parse_from_str(s: &str) -> anyhow::Result<Self> {
        Ok(Self(uuid::Uuid::parse_str(s)?))
    }

    pub fn is_valid(&self) -> bool {
        self.0.get_version_num() == 4
    }
}

/// OS information
#[derive(serde::Serialize, serde::Deserialize)]
#[serde(rename = "os")]
pub struct OSXML {
    pub r#type: OSTypeXML,
}

/// OS Type information
#[derive(serde::Serialize, serde::Deserialize)]
#[serde(rename = "os")]
pub struct OSTypeXML {
    #[serde(rename(serialize = "@arch"))]
    pub arch: String,
    #[serde(rename = "$value")]
    pub body: String,
}

#[derive(serde::Serialize, serde::Deserialize)]
#[serde(rename = "memory")]
pub struct DomainMemoryXML {
    #[serde(rename(serialize = "@unit"))]
    pub unit: String,

    #[serde(rename = "$value")]
    pub memory: String,
}

/// Domain information, see https://libvirt.org/formatdomain.html
#[derive(serde::Serialize, serde::Deserialize)]
#[serde(rename = "domain")]
pub struct DomainXML {
    /// Domain type (kvm)
    #[serde(rename(serialize = "@type"))]
    pub r#type: String,

    pub name: String,
    pub uuid: Option<DomainXMLUuid>,
    pub genid: Option<uuid::Uuid>,
    pub title: Option<String>,
    pub description: Option<String>,
    pub os: OSXML,

    /// The maximum allocation of memory for the guest at boot time
    pub memory: DomainMemoryXML,
}
